boss.dummies - heros-boss unknown documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# boss.dummies

## Classes

`Dummy` |
`PolledDatasourceDummy` |

## Module Contents

class boss.dummies.Dummy
  val = 3
  read_temp(min: int, max: int) → float
  hello() → str

class boss.dummies.PolledDatasourceDummy

  Bases: `Dummy`

  foovar: str = ''
  testme: int = 0
  _observable_data()